@@ -849,7 +849,8 @@ class Sofa():
         if data_str:
             for key, value in data_type[data_str].items():
 
-                # hard to test. included to detect problems with future conventions
+                # hard to test. included to detect problems with future
+                # conventions
                 if not hasattr(self, key):
                     current_error += (
                         f"- {key} must be contained if"
@@ -1100,7 +1101,8 @@ class Sofa():
         for key in self._convention.keys():
 
             # skip optional fields if requested
-            if not self._mandatory(self._convention[key]["flags"]) and mandatory:
+            if not self._mandatory(self._convention[key]["flags"]) \
+                    and mandatory:
                 continue
 
             # get the default value
@@ -1439,6 +1441,7 @@ def read_sofa(filename, verify=True, version="latest"):
                 _add_custom_api_entry(sofa, "GLOBAL_" + attr, value, None,
                                       None, "attribute")
                 custom.append("GLOBAL_" + attr)
+                sofa._protected = False
             else:
                 setattr(sofa, "GLOBAL_" + attr, value)
 
@@ -1460,6 +1463,7 @@ def read_sofa(filename, verify=True, version="latest"):
                 _add_custom_api_entry(sofa, var.replace(".", "_"), value, None,
                                       dimensions, dtype)
                 custom.append(var.replace(".", "_"))
+                sofa._protected = False
 
             # load variable attributes
             for attr in [a for a in file[var].ncattrs() if a not in skip]:
@@ -1471,6 +1475,7 @@ def read_sofa(filename, verify=True, version="latest"):
                         sofa, var.replace(".", "_") + "_" + attr, value, None,
                         None, "attribute")
                     custom.append(var.replace(".", "_") + "_" + attr)
+                    sofa._protected = False
                 else:
                     setattr(sofa, var.replace(".", "_") + "_" + attr, value)
 
@@ -1558,7 +1563,8 @@ def write_sofa(filename: str, sofa: Sofa, version="latest", compression=4):
             # lax definition:
             #   sofa._convention[key]["type"] == "attribute":
             # strict definition:
-            #   ("_" in key and not key.startswith("Data_")) or key.count("_") > 1
+            #   ("_" in key and not key.startswith("Data_")) or \
+            #       key.count("_") > 1
             #
             # The strict definition is implicitly included in the SOFA standard
             # since underscores only occur for variables starting with Data_
